package com.ruoyi.project.base.service;

import java.util.List;
import com.ruoyi.project.base.domain.TBasePlant;

/**
 * 装置Service接口
 *
 * @author ruoyi
 * @date 2022-11-14
 */
public interface ITBasePlantService
{
    /**
     * 查询装置
     *
     * @param id 装置主键
     * @return 装置
     */
    public TBasePlant selectTBasePlantById(Long id);
    public TBasePlant selectTBasePlantByName(String name);

    /**
     * 查询装置列表
     *
     * @param tBasePlant 装置
     * @return 装置集合
     */
    public List<TBasePlant> selectTBasePlantList(TBasePlant tBasePlant);
    public List<TBasePlant> selectAllPlantName();

    /**
     * 新增装置
     *
     * @param tBasePlant 装置
     * @return 结果
     */
    public int insertTBasePlant(TBasePlant tBasePlant);

    /**
     * 修改装置
     *
     * @param tBasePlant 装置
     * @return 结果
     */
    public int updateTBasePlant(TBasePlant tBasePlant);
    public int updateTBasePlantByPlantIds(TBasePlant tBasePlant);

    /**
     * 批量删除装置
     *
     * @param ids 需要删除的装置主键集合
     * @return 结果
     */
    public int deleteTBasePlantByIds(Long[] ids);

    /**
     * 删除装置信息
     *
     * @param id 装置主键
     * @return 结果
     */
    public int deleteTBasePlantById(Long id);
}
